@@ -15,7 +15,9 @@
                     $this.after(options.placeholder).after(lookup_link($this.attr("id"),$(options.content_type).val()));
                 }
                 // lookup
-                lookup_id($this, options); // lookup when loading page
+                if ($(options.content_type).val()) {
+                    lookup_id($this, options); // lookup when loading page
+                }
                 $this.bind("change focus keyup blur", function() { // id-handler
                     lookup_id($this, options);
                 });
@@ -48,8 +50,8 @@
     var update_lookup = function(elem, options) {
         var obj = $(options.object_id);
         obj.val('');
-        obj.next().remove();
-        obj.next().remove();
+        obj.parent().find('a.related-lookup').remove();
+        obj.parent().find('.grp-placeholder-related-generic').remove();
         if ($(elem).val()) {
             obj.after(options.placeholder).after(lookup_link(obj.attr('id'),$(elem).val()));
         }
@@ -72,7 +74,7 @@
     };
     
     $.fn.grp_related_generic.defaults = {
-        placeholder: '<div class="grp-placeholder-related-generic"></div>',
+        placeholder: '<div class="grp-placeholder-related-generic" style="display:none"></div>',
         repr_max_length: 30,
         lookup_url: '',
         content_type: '',
