@@ -69,7 +69,7 @@ def m2m_lookup(request):
                         try:
                             obj = model.objects.get(pk=obj_id)
                             data.append({"value":obj.pk,"label":get_label(obj)})
-                        except obj.DoesNotExist:
+                        except model.DoesNotExist:
                             data.append({"value":obj_id,"label":_("?")})
             return HttpResponse(simplejson.dumps(data), mimetype='application/javascript')
     data = [{"value":None,"label":""}]
@@ -101,14 +101,13 @@ def autocomplete_lookup(request):
                 search_qs.dup_select_related(qs)
                 search_qs = search_qs.filter(reduce(operator.or_, search))
                 qs = qs & search_qs
-            data = [{"value":f.pk,"label":u'%s' % get_label(f)} for f in qs[:AUTOCOMPLETE_LIMIT]]
+            data = [{"value":f.pk,"label":get_label(f)} for f in qs[:AUTOCOMPLETE_LIMIT]]
             label = ungettext(
                 '%(counter)s result',
                 '%(counter)s results',
-            len(data)) % {
+                len(data)) % {
                 'counter': len(data),
             }
-            #data.insert(0, {"value":None,"label":label})
             return HttpResponse(simplejson.dumps(data), mimetype='application/javascript')
     data = [{"value":None,"label":_("Server error")}]
     return HttpResponse(simplejson.dumps(data), mimetype='application/javascript')
